%global momorel 1

Summary: Objective Caml compiler and programming environment
Name: ocaml
Version: 3.09.2
Release: %{momorel}m
Group: Development/Languages
License: "QPL/LGPL"
URL: http://caml.inria.fr/

%NoSource 0 http://caml.inria.fr/distrib/ocaml-3.09/ocaml-3.09.2.tar.bz2 63428ce7e114520e8f529c9ca809a1b0
%NoSource 1 http://caml.inria.fr/distrib/ocaml-3.09/ocaml-3.09-refman.html.tar.gz b25eb211bf91bcaa536b12d12731ceec
%NoSource 2 http://caml.inria.fr/distrib/ocaml-3.09/ocaml-3.09-refman.pdf 6ed0c6b1167dbf6c1cb10a78d302bc00
%NoSource 3 http://caml.inria.fr/distrib/ocaml-3.09/ocaml-3.09-refman.info.tar.gz 280160b1fc7c8513074c3fda0446de29

Patch0: ocaml-rpath.patch
Patch1: ocaml-user-cflags.patch

Prereq: info
BuildPreReq: ncurses-devel
BuildPreReq: gdbm-devel
BuildPreReq: tcl-devel, tk-devel
BuildPreReq: emacs, perl
BuildPreReq: libICE-devel
BuildPreReq: libSM-devel
BuildPreReq: libX11-devel
BuildPreReq: libXaw-devel
BuildPreReq: libXext-devel
BuildPreReq: libXft-devel
BuildPreReq: libXmu-devel
BuildPreReq: libXrender-devel
BuildPreReq: libXt-devel
BuildPreReq: mesa-libGL-devel
BuildPreReq: mesa-libGLU-devel
BuildRoot: %{_tmppath}/%{name}-%{version}-root


%description
Objective Caml is a high-level, strongly-typed, functional and
object-oriented programming language from the ML family of languages.

This package comprises two batch compilers (a fast bytecode compiler
and an optimizing native-code compiler), an interactive toplevel system,
parsing tools (Lex,Yacc,Camlp4), a replay debugger, a documentation generator,
and a comprehensive library.


%package -n labltk
Group: Development/Languages
Summary: Tk bindings for Objective Caml
Requires: ocaml = %{version}-%{release}

%description -n labltk
A library for interfacing Objective Caml with the scripting language
Tcl/Tk. It include the OCamlBrowser code editor / library browser.


%package -n camlp4
Group: Development/Languages
Summary: Pre-Processor-Pretty-Printer for OCaml
Requires: ocaml = %{version}-%{release}

%description -n camlp4
Camlp4 is a Pre-Processor-Pretty-Printer for OCaml, parsing a source
file and printing some result on standard output.


%package ocamldoc
Group: Development/Languages
Summary: Documentation generator for OCaml
Requires: ocaml = %{version}-%{release}

%description ocamldoc
Documentation generator for Objective Caml.


%package emacs
Group: Development/Languages
Summary: Emacs mode for Objective Caml
Requires: ocaml = %{version}-%{release}
Requires: emacs

%description emacs
Emacs mode for Objective Caml.


%package docs
Group: Development/Languages
Summary: Documentation for OCaml
Requires: ocaml = %{version}-%{release}

%description docs
Documentation for Objective Caml.


%prep
%setup -q -T -b 0
%setup -q -T -D -a 1
%setup -q -T -D -a 3
%patch0 -p1 -b .rpath
%patch1 -p1 -b .cflags

%__cp %{SOURCE2} refman.pdf


%build
CFLAGS="$RPM_OPT_FLAGS" ./configure \
    -bindir %{_bindir} \
    -libdir %{_libdir}/ocaml \
    -x11lib %{_libdir} \
    -x11include %{_includedir} \
    -mandir %{_mandir}/man1
make world opt opt.opt
# %{?_smp_mflags} breaks the build
(cd emacs; make ocamltags)


%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}
%makeinstall BINDIR=%{buildroot}%{_bindir} LIBDIR=%{buildroot}%{_libdir}/ocaml MANDIR=%{buildroot}%{_mandir}
perl -pi -e "s|^%{buildroot}||" %{buildroot}%{_libdir}/ocaml/ld.conf
(
    cd emacs;
    make install BINDIR=%{buildroot}%{_bindir} EMACSDIR=%{buildroot}%{_datadir}/emacs/site-lisp/caml
    make install-ocamltags BINDIR=%{buildroot}%{_bindir}
)
(
    %__mkdir_p %{buildroot}%{_infodir};
    cd infoman; %__cp ocaml*.gz %{buildroot}%{_infodir}
)


%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}


%post
/sbin/install-info \
    --entry "* ocaml: (ocaml).	 The Objective Caml compiler and programming environment" \
    --section "Programming Languages" \
    %{_infodir}/%{name}.info \
    %{_infodir}/dir 2>/dev/null || :


%preun
if [ $1 -eq 0 ]; then
    /sbin/install-info --delete %{_infodir}/%{name}.info %{_infodir}/dir 2>/dev/null || :
fi


%files
%defattr(-,root,root,-)
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man3/*
%{_libdir}/ocaml
%{_infodir}/*
%exclude %{_bindir}/camlp4*
%exclude %{_bindir}/mkcamlp4
%exclude %{_bindir}/ocpp
%exclude %{_bindir}/labltk
%exclude %{_bindir}/ocamltags
%exclude %{_bindir}/ocamlbrowser
%exclude %{_bindir}/ocamldoc*
%exclude %{_libdir}/ocaml/camlp4
%exclude %{_libdir}/ocaml/labltk
%exclude %{_libdir}/ocaml/ocamldoc
%exclude %{_mandir}/man1/camlp4*
%exclude %{_mandir}/man1/mkcamlp4*
%exclude %{_libdir}/ocaml/stublibs/dlllabltk.so
%exclude %{_libdir}/ocaml/stublibs/dlltkanim.so
%doc README LICENSE Changes


%files -n labltk
%defattr(-,root,root,-)
%{_bindir}/labltk
%{_bindir}/ocamlbrowser
%{_libdir}/ocaml/labltk
%{_libdir}/ocaml/stublibs/dlllabltk.so
%{_libdir}/ocaml/stublibs/dlltkanim.so
%doc otherlibs/labltk/examples_labltk
%doc otherlibs/labltk/examples_camltk


%files -n camlp4
%defattr(-,root,root,-)
%{_bindir}/camlp4*
%{_bindir}/mkcamlp4
%{_bindir}/ocpp
%{_libdir}/ocaml/camlp4
%{_mandir}/man1/camlp4*
%{_mandir}/man1/mkcamlp4*


%files ocamldoc
%defattr(-,root,root,-)
%{_bindir}/ocamldoc*
%{_libdir}/ocaml/ocamldoc
%doc ocamldoc/Changes.txt


%files docs
%defattr(-,root,root,-)
%doc refman.pdf htmlman


%files emacs
%defattr(-,root,root,-)
%{_datadir}/emacs/site-lisp/caml
%{_bindir}/ocamltags
%doc emacs/README


%changelog
* Wed Jul 12 2006 NAKAYA Toshiharu <nakaya@momonga-linux.org>
- (3.09.2-1m)
- import from FC-5
-* Sun Apr 30 2006 Gerard Milmeister <gemi@bluewin.ch> - 3.09.2-1
-- new version 3.09.2
-
-* Fri Feb 17 2006 Gerard Milmeister <gemi@bluewin.ch> - 3.09.1-2
-- Rebuild for Fedora Extras 5
-
-* Thu Jan  5 2006 Gerard Milmeister <gemi@bluewin.ch> - 3.09.1-1
-- new version 3.09.1
-
-* Sun Jan  1 2006 Gerard Milmeister <gemi@bluewin.ch> - 3.09.0-1
-- new version 3.09.0
-
-* Sun Sep 11 2005 Gerard Milmeister <gemi@bluewin.ch> - 3.08.4-1
-- New Version 3.08.4
-
-* Wed May 25 2005 Toshio Kuratomi <toshio-tiki-lounge.com> - 3.08.3-5
-- Bump and re-release as last build failed due to rawhide syncing.
-
-* Sun May 22 2005 Toshio Kuratomi <toshio-tiki-lounge.com> - 3.08.3-4
-- Fix for gcc4 and the 32 bit assembly in otherlibs/num.
-- Fix to allow compilation with RPM_OPT_FLAG defined -O level.
-
-* Sun May 22 2005 Jeremy Katz <katzj@redhat.com> - 3.08.3-3
-- rebuild on all arches
-
-* Fri Apr  7 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
-- rebuilt
-
-* Sat Mar 26 2005 Gerard Milmeister <gemi@bluewin.ch> - 3.08.3-1
-- New Version 3.08.3
-
-* Sat Feb 12 2005 Gerard Milmeister <gemi@bluewin.ch> - 0:3.08.2-2
-- Added patch for removing rpath from shared libs
-
-* Sat Feb 12 2005 Gerard Milmeister <gemi@bluewin.ch> - 0:3.08.2-1
-- New Version 3.08.2
-
-* Thu Dec 30 2004 Thorsten Leemhuis <fedora[AT]leemhuis[DOT]info> - 0:3.07-6
-- add -x11lib %%{_prefix}/X11R6/%%{_lib} to configure; fixes labltk build
-  on x86_64
-
-* Tue Dec  2 2003 Gerard Milmeister <gemi@bluewin.ch> - 0:3.07-0.fdr.5
-- ocamldoc -> ocaml-ocamldoc
-- ocaml-doc -> ocaml-docs
-
-* Fri Nov 28 2003 Gerard Milmeister <gemi@bluewin.ch> - 0:3.07-0.fdr.4
-- Make separate packages for labltk, camlp4, ocamldoc, emacs and documentation
-
-* Thu Nov 27 2003 Gerard Milmeister <gemi@bluewin.ch> - 0:3.07-0.fdr.2
-- Changed license tag
-- Register info files
-- Honor RPM_OPT_FLAGS
-- New Patch
-
-* Fri Oct 31 2003 Gerard Milmeister <gemi@bluewin.ch> - 0:3.07-0.fdr.1
-- First Fedora release
-
-* Mon Oct 13 2003 Axel Thimm <Axel.Thimm@physik.fu-berlin.de>
-- Updated to 3.07.
-
-* Wed Apr  9 2003 Axel Thimm <Axel.Thimm@physik.fu-berlin.de>
-- Rebuilt for Red Hat 9.
-
-* Tue Nov 26 2002 Axel Thimm <Axel.Thimm@physik.fu-berlin.de>
-- Added %{_mandir}/mano/* entry
